@@ -5,14 +5,13 @@ import sys
 import traceback
 import uuid
 from datetime import datetime, timedelta
-# from pathlib import Path
 from urllib.parse import quote
 
 import dateutil.parser
 import pytz
 import yaml
 
-from ident import generate_pid, check_pid, correct_pid, generate_id12
+from sysnet_pyutils.ident import generate_pid, check_pid, correct_pid, generate_id12
 
 TZ = os.getenv('TZ', 'Europe/Prague')
 DEBUG = os.getenv("DEBUG", 'True').lower() in ('true', '1', 't')
